FixedSelection

Struct FixedSelection 

pub struct FixedSelection {
    model: BoundObject<ListModel>,
    pub(super) item_equivalence_fn: RefCell<Option<Box<dyn Fn(&Object, &Object) -> bool>>>,
    selected: Cell<u32>,
    selected_item: RefCell<Option<Object>>,
    is_empty: PhantomData<bool>,
}

Fields

model: BoundObject<ListModel>

The underlying model.

item_equivalence_fn: RefCell<Option<Box<dyn Fn(&Object, &Object) -> bool>>>

The function to use to test for equivalence of two items.

It is used when checking if an object still present when the underlying model changes. Which means that if there are two equivalent objects at the same time in the underlying model, the selected item might change unexpectedly between those two objects.

If this is not set, the Eq implementation is used, meaning that they must be the same object.

selected: Cell<u32>

The position of the selected item.

selected_item: RefCell<Option<Object>>

The selected item.

is_empty: PhantomData<bool>

Whether the model is empty.

Implementations

Source

impl FixedSelection

fn register_type()

Registers the type only once.

Source

impl FixedSelection

pub fn downgrade(&self) -> <Self as Downgrade>::Weak

Source

impl FixedSelection

fn set_model(&self, model: Option<ListModel>)

Set the underlying model.

fn set_selected(&self, position: u32)

Set the selected item by its position.

fn set_selected_item(&self, item: Option<Object>)

Set the selected item.

fn is_empty(&self) -> bool

Whether the model is empty.

fn items_changed_cb( &self, model: &ListModel, position: u32, removed: u32, added: u32, )

Handle when items changed in the underlying model.